autoStart property
If true, the ticker will start automatically when the widget is initialized. If this is set to false, the ticker will not start automatically when the widget is initialized. To start the ticker, use the startTicker method.
Alternatively to start the ticker from descendant widgets, use the TickingInterface.startTicker method. Example:
final ticking = TickingWidget.of(context);
ticking.startTicker();
The default value is true.
Implementation
bool autoStart = true;