setMode method
Sets the mode of the ticker to the given TickingMode.
Implementation
@override
void setMode(TickingMode mode) {
this.mode = mode;
if (mounted) setState(() {});
}
Sets the mode of the ticker to the given TickingMode.
@override
void setMode(TickingMode mode) {
this.mode = mode;
if (mounted) setState(() {});
}