mode property
The mode of ticking. It can be millisecond, second, minute, or hour. This is used to determine when to rebuild the widget.
For example, if the mode is set to TickingMode.second, the widget will rebuild every second.
Implementation
@override
TickingMode mode = TickingMode.second;